@@ -89,7 +89,7 @@ c.copula.theta.C2 <- dH2$c.copula.theta
 derp1.dereta1   <- pd1$derp1.dereta1    # -dnorm(-eta1) 
 
 
-Cc <- mm(c.copula.be1.C1 - c.copula.be1.C2, min.pr = VC$min.pr, max.pr = VC$max.pr) 
+Cc <- c.copula.be1.C1 - c.copula.be1.C2 # mm(c.copula.be1.C1 - c.copula.be1.C2, min.pr = VC$min.pr, max.pr = VC$max.pr) 
 C  <- Cc*derp1.dereta1[VC$inde] 
 
 Cs    <- c.copula.theta.C1  - c.copula.theta.C2
