@@ -2,6 +2,8 @@ print.AT <- function(x, ...){
 
 
 
+
+
 if(x$triv == FALSE){
 
 
@@ -25,11 +27,14 @@ if(x$mar2 %in% x$bl || ( !(x$mar2 %in% x$bl) && x$eq == 1) ) cat("\nTreatment ef
 
 if( !(x$mar2 %in% x$bl) && x$eq == 2) cat("\nTreatment effect with ",(1-x$prob.lev)*100,"% interval:\n\n",sep="")
 
-cat(es[2]," (",es[1],",",es[3],")\n\n",sep="")
+if(x$Model != "ROY") cat(es[2]," (",es[1],",",es[3],")\n\n",sep="")
 
 }
 
 
+
+
+
 }
 
 
@@ -47,6 +52,20 @@ cat(es[2]," (",es[1],",",es[3],")\n\n",sep="")
 
 
 
+if(x$Model == "ROY"){
+
+
+es <- format(x$res, digits = 3, trim=TRUE)
+
+cat("\nMarginal effect with ",(1-x$prob.lev)*100,"% interval:\n\n",sep="")
+cat(es[2]," (",es[1],",",es[3],")\n\n",sep="")
+
+
+
+}
+
+
+
 
 
 invisible(x)
