@@ -1,4 +1,288 @@
-pscr <- function(x, lind, m1l, m2l, cont1par, cont2par, cont3par, type = "copR", digits, signif.stars, m3l = NULL, ...){
+pscr <- function(x, lind, m1l, m2l, cont1par, cont2par, cont3par, type = "copR", digits, signif.stars, m3l = NULL, lind2 = NULL, ...){
+
+
+if(type == "ROY"){
+
+
+  cat("\n\nEQUATION 1")
+  cat("\nLink function for mu.1:",m1l,"\n")
+  cat("Formula: "); print(x$formula[[1]])
+  cat("\n") 
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP1,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp1!=0){ 
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP1,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }
+
+
+
+  cat("\nEQUATION 2")
+  cat("\nLink function for mu.2:",m2l,"\n")
+  cat("Formula: "); print(x$formula[[2]])
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP2,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp2!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP2,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }  
+    
+    
+
+  cat("\nEQUATION 3")
+  cat("\nLink function for mu.3:",m3l,"\n")
+  cat("Formula: "); print(x$formula[[3]])
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP3,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp3!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP3,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }   
+
+
+
+#***********
+if(length(x$formula) > 3 && x$margins[2] %in% cont1par && x$margins[3] %in% cont1par){
+
+  cat("\nEQUATION 4")
+  cat("\nLink function for theta.1:",lind,"\n") 
+  cat("Formula: "); print(x$formula[[4]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP4,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp4!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP4,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+
+  cat("\nEQUATION 5")
+  cat("\nLink function for theta.2:",lind2,"\n") 
+  cat("Formula: "); print(x$formula[[5]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP5,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp5!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP5,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+}
+
+
+#***********
+if(length(x$formula) > 3 && x$margins[2] %in% c(cont2par) && x$margins[3] %in% c(cont2par)){
+
+
+  cat("\nEQUATION 4")
+  if(x$margins[2] != "BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
+  cat("Formula: "); print(x$formula[[4]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP4,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp4!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP4,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+
+  cat("\nEQUATION 5")
+  if(x$margins[3] != "BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")
+  cat("Formula: "); print(x$formula[[5]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP5,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp5!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP5,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    } 
+
+
+  cat("\nEQUATION 6")
+  cat("\nLink function for theta.1:",lind,"\n") 
+  cat("Formula: "); print(x$formula[[6]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP6,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp6!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP6,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+
+  cat("\nEQUATION 7")
+  cat("\nLink function for theta.2:",lind2,"\n") 
+  cat("Formula: "); print(x$formula[[7]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP7,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp7!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP7,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+}
+
+
+
+
+#***********
+if(length(x$formula) > 3 && x$margins[2] %in% c(cont3par) && x$margins[3] %in% c(cont3par)){
+
+
+  cat("\nEQUATION 4")
+  cat("\nLink function for sigma.1:","log","\n") 
+  cat("Formula: "); print(x$formula[[4]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP4,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp4!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP4,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+
+  cat("\nEQUATION 5")
+  cat("\nLink function for sigma.2:","log","\n")
+  cat("Formula: "); print(x$formula[[5]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP5,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp5!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP5,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    } 
+    
+    
+    
+    
+    
+  cat("\nEQUATION 6")
+  cat("\nLink function for nu.1:","log","\n")  
+  cat("Formula: "); print(x$formula[[6]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP6,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp6!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP6,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+
+  cat("\nEQUATION 7")
+  cat("\nLink function for nu.2:","log","\n") 
+  cat("Formula: "); print(x$formula[[7]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP7,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp7!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP7,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    } 
+    
+    
+    
+    
+    
+    
+    
+    
+
+
+  cat("\nEQUATION 8")
+  cat("\nLink function for theta.1:",lind,"\n") 
+  cat("Formula: "); print(x$formula[[8]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP8,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp8!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP8,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+
+  cat("\nEQUATION 9")
+  cat("\nLink function for theta.2:",lind2,"\n") 
+  cat("Formula: "); print(x$formula[[9]]) 
+  cat("\n")
+  cat("Parametric coefficients:\n")
+  printCoefmat(x$tableP9,digits = digits, signif.stars = signif.stars,na.print = "NA",...)
+  cat("\n")
+
+    if(x$l.sp9!=0){
+    cat("Smooth components' approximate significance:\n")
+    printCoefmat(x$tableNP9,digits = digits, signif.stars = signif.stars,has.Pvalue = TRUE,na.print = "NA",cs.ind = 1,...)
+    cat("\n")
+    }    
+
+}
+
+
+
+
+
+
+}
+
+
+
+
+
+
+
+
+if(type != "ROY"){
+
+
+
+
+
+
+
 
 if(type == "biv"){
 
@@ -1492,7 +1776,7 @@ if(!is.null(x$tableP3) && !is.null(x$tableP4) && !is.null(x$tableP5)  ){
 }
 
 
-
+} # !ROY
 
                 
 }
